# onnx.checker

## CheckerContext

```{eval-rst}
.. autoclass:: onnx.checker.DEFAULT_CONTEXT
    :members:
```

## check_value_info

```{eval-rst}
.. autofunction:: onnx.checker.check_value_info
```

## check_tensor

```{eval-rst}
.. autofunction:: onnx.checker.check_tensor
```

## check_attribute

```{eval-rst}
.. autofunction:: onnx.checker.check_attribute
```

## check_node

```{eval-rst}
.. autofunction:: onnx.checker.check_node
```

## check_function

```{eval-rst}
.. autofunction:: onnx.checker.check_function
```

## check_graph

```{eval-rst}
.. autofunction:: onnx.checker.check_graph
```

## check_model

```{eval-rst}
.. autofunction:: onnx.checker.check_model
```
